@@ -145,16 +145,33 @@ function processDeployment($queue_id, $config, $DockerAPI, $containerQueue, $db)
                 throw new Exception("Invalid container name generated from domain: " . $config['primary_fqdn']);
             }
             
-            $result = $DockerAPI->create_container([
+            // Prepare container configuration with proper data types
+            $container_config = [
                 'name' => $container_name,
                 'image' => $container_type_info['base_image'],
-                'cpu' => $config['cpu_per_container'],
-                'memory' => $config['memory_per_container'] . 'M',
+                'cpu' => (float)$config['cpu_per_container'],
+                'memory' => (int)$config['memory_per_container'],
                 'user' => $config['primary_domain_row']['username'],
-                'startup_env' => $container_type_info['startup_env'],
-                'mount_options' => $container_type_info['mount_options'],
-                'listen_port' => $container_type_info['listen_port']
-            ]);
+                'listen_port' => (int)$container_type_info['listen_port']
+            ];
+            
+            // Add startup_env if it exists and is valid JSON
+            if (!empty($container_type_info['startup_env'])) {
+                $startup_env = json_decode($container_type_info['startup_env'], true);
+                if ($startup_env !== null) {
+                    $container_config['startup_env'] = $startup_env;
+                }
+            }
+            
+            // Add mount_options if it exists and is valid JSON
+            if (!empty($container_type_info['mount_options'])) {
+                $mount_options = json_decode($container_type_info['mount_options'], true);
+                if ($mount_options !== null) {
+                    $container_config['mount_options'] = $mount_options;
+                }
+            }
+            
+            $result = $DockerAPI->create_container($container_config);
             
             // Log only essential information, not sensitive config
             log_message("Docker API result for container $i: success=" . ($result['success'] ? 'true' : 'false') . 
